@@ -1,11 +1,13 @@
 from .source_file.client import Client as files
 from .destination_sftp_json.client import SftpClient
 from .destination_azblob.destination import DestinationAzBlob
-from .source_IPFS.client import IPFS
+from .destination_IPFS.client import IPFSDestination
+from .source_IPFS.client import IPFSSource
 
 __all__ = [
     'files',
     'SftpClient',
     'DestinationAzBlob',
-    'IPFS'
+    'IPFSDestination',
+    'IPFSSource'
 ]
